[commit: ghc] master: Spelling in comments [ci skip] (3211fa0)

git at git.haskell.org git at git.haskell.org
Fri Feb 10 12:41:41 UTC 2017


Repository : ssh://git@git.haskell.org/ghc

On branch  : master
Link       : http://ghc.haskell.org/trac/ghc/changeset/3211fa06744731ec117219fe50a304e952e072ef/ghc

>---------------------------------------------------------------

commit 3211fa06744731ec117219fe50a304e952e072ef
Author: Gabor Greif <ggreif at gmail.com>
Date:   Fri Feb 10 09:12:12 2017 +0100

    Spelling in comments [ci skip]


>---------------------------------------------------------------

3211fa06744731ec117219fe50a304e952e072ef
 compiler/specialise/Specialise.hs | 2 +-
 compiler/typecheck/TcInstDcls.hs  | 2 +-
 compiler/typecheck/TcSMonad.hs    | 6 +++---
 compiler/typecheck/TcType.hs      | 2 +-
 rts/Adjustor.c                    | 2 +-
 rules/hs-suffix-way-rules.mk      | 6 +++---
 6 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/compiler/specialise/Specialise.hs b/compiler/specialise/Specialise.hs
index 2b4d9f5..0090417 100644
--- a/compiler/specialise/Specialise.hs
+++ b/compiler/specialise/Specialise.hs
@@ -145,7 +145,7 @@ becomes
                          fl
 
 We still have recusion for non-overloaded functions which we
-speciailise, but the recursive call should get specialised to the
+specialise, but the recursive call should get specialised to the
 same recursive version.
 
 
diff --git a/compiler/typecheck/TcInstDcls.hs b/compiler/typecheck/TcInstDcls.hs
index 9298b10..95d33dd 100644
--- a/compiler/typecheck/TcInstDcls.hs
+++ b/compiler/typecheck/TcInstDcls.hs
@@ -988,7 +988,7 @@ tcSuperClasses :: DFunId -> Class -> [TcTyVar] -> [EvVar] -> [TcType]
 --    $Ordp1 = /\a \(d:Ord a). dfunEqList a (sc_sel d)
 --
 -- See Note [Recursive superclasses] for why this is so hard!
--- In effect, be build a special-purpose solver for the first step
+-- In effect, we build a special-purpose solver for the first step
 -- of solving each superclass constraint
 tcSuperClasses dfun_id cls tyvars dfun_evs inst_tys dfun_ev_binds sc_theta
   = do { (ids, binds, implics) <- mapAndUnzip3M tc_super (zip sc_theta [fIRST_TAG..])
diff --git a/compiler/typecheck/TcType.hs b/compiler/typecheck/TcType.hs
index 2dffed2..0e1ad7f 100644
--- a/compiler/typecheck/TcType.hs
+++ b/compiler/typecheck/TcType.hs
@@ -903,7 +903,7 @@ rewritableTyVarsOfType ty
     go (TyConApp _ tys) = rewritableTyVarsOfTypes tys
     go (AppTy fun arg)  = go fun `unionVarSet` go arg
     go (FunTy arg res)  = go arg `unionVarSet` go res
-    go ty@(ForAllTy {}) = pprPanic "rewriteableTyVarOfType" (ppr ty)
+    go ty@(ForAllTy {}) = pprPanic "rewritableTyVarOfType" (ppr ty)
     go (CastTy ty _co)  = go ty
     go (CoercionTy _co) = emptyVarSet
 
diff --git a/rts/Adjustor.c b/rts/Adjustor.c
index 5f047b3..9f5a000 100644
--- a/rts/Adjustor.c
+++ b/rts/Adjustor.c
@@ -78,7 +78,7 @@ extern void *adjustorCode;
  * recover the writable address, we subtract 1 word from the executable
  * address and fetch. This works because Linux kernel magic gives us two
  * pointers with different addresses that refer to the same memory. Whatever
- * you write into the writeable address can be read back at the executable
+ * you write into the writable address can be read back at the executable
  * address. This method is very efficient.
  *
  * On iOS this breaks for two reasons: 1. the two pointers do not refer to
diff --git a/rules/hs-suffix-way-rules.mk b/rules/hs-suffix-way-rules.mk
index d7b4520..b77806f 100644
--- a/rules/hs-suffix-way-rules.mk
+++ b/rules/hs-suffix-way-rules.mk
@@ -55,8 +55,8 @@ else
 # needs to make a choice which of the above two implicit rules to follow (it
 # never runs 2 recipes for the same target, unless double colon rules are
 # used, which we don't), logically it will choose the first rule: Lexer.o will
-# depend on Lexer.hs in the build directory, that file will be build, and then
-# Lexer.o can be build.
+# depend on Lexer.hs in the build directory, that file will be built, and then
+# Lexer.o can be built.
 #
 # In an sdist however, Lexer.hs is present in the source directory. It was
 # copied there during the creation of the sdist by a rule in
@@ -65,7 +65,7 @@ else
 # building from sdist and 2) the sdist creation process renamed Lexer.x to
 # Lexer.x.source. So normally make would now choose the second rule: Lexer.o
 # will depend on Lexer.hs in the source directory, for which nothing needs to
-# be done, and then Lexer.o can be build.
+# be done, and then Lexer.o can be built.
 #
 # There is however another actor in play, a rule in sdist-ghc-file.mk, which
 # after after instantiating with the same directory ($1=utils/genprimops) and



More information about the ghc-commits mailing list
diff --git a/compiler/typecheck/TcSMonad.hs b/compiler/typecheck/TcSMonad.hs
index 1be1724..4fb0632 100644
--- a/compiler/typecheck/TcSMonad.hs
+++ b/compiler/typecheck/TcSMonad.hs
@@ -797,7 +797,7 @@ Theorem [Stability under extension]
    is an inert generalised substitution.
 
 Conditions (T1-T3) are established by the canonicaliser
-Conditions (K1-K3) are established by TcSMonad.kickOutRewriteable
+Conditions (K1-K3) are established by TcSMonad.kickOutRewritable
 
 The idea is that
 * (T1-2) are guaranteed by exhaustively rewriting the work-item
@@ -1077,7 +1077,7 @@ work?
 * CDictCan (C tys) or CFunEqCan (F tys ~ fsk):
   Yes if the inert set could rewrite tys to make the class constraint,
   or type family, fire.  That is, yes if the inert_eqs intersects
-  with the free vars of tys.  For this test we use rewriteableTyVars
+  with the free vars of tys.  For this test we use rewritableTyVars
   which ignores casts and coercions in tys, because rewriting the
   casts or coercions won't make the thing fire more often.
 
@@ -1510,7 +1510,7 @@ kick_out_rewritable new_fr new_tv ics@(IC { inert_eqs      = tv_eqs
     -- Kick it out if the new CTyEqCan can rewrite the inert one
     -- See Note [kickOutRewritable]
     -- Used only on CFunEqCan, CDictCan, CIrredCan
     --   hence no forallls in (ctEvPred ev), hence rewriteableTyVarsOfType ok
     kick_out_ct ct | let ev = ctEvidence ct
                    = fr_may_rewrite (ctEvFlavourRole ev)
                    && new_tv `elemVarSet` rewritableTyVarsOfType (ctEvPred ev)
@@ -1510,7 +1510,7 @@ kick_out_rewritable new_fr new_tv ics@(IC { inert_eqs      = tv_eqs
     -- See Note [kickOutRewritable]
     -- Used only on CFunEqCan, CDictCan, CIrredCan
-    --   hence no forallls in (ctEvPred ev), hence rewriteableTyVarsOfType ok
+    --   hence no foralls in (ctEvPred ev), hence rewritableTyVarsOfType ok
     kick_out_ct ct | let ev = ctEvidence ct
                    = fr_may_rewrite (ctEvFlavourRole ev)